import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AnswerService } from '../service/answer.service';
import {
  CDTO_answer,
  CVO_answer,
  FVO_answer,
  QDTO_answer,
  QVO_answer,
  UDTO_answer,
  UVAO_answer,
} from '../interface/answer.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['答案表'])
@Controller('/answer')
export class AnswerController extends BaseController {
  @Inject()
  service: AnswerService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_answer })
  async create(@Body() data: CDTO_answer) {
    const dbData = await this.service.create(data);
    const result = new CVO_answer(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_answer })
  async query(
    @Query() filter: QDTO_answer,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_answer(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_answer })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_answer(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_answer })
  async update(@Param('id') id: string, @Body() body: UDTO_answer) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
