import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { QuestionnaireService } from '../service/questionnaire.service';
import {
  CDTO_questionnaire,
  CVO_questionnaire,
  FVO_questionnaire,
  QDTO_questionnaire,
  QVO_questionnaire,
  UDTO_questionnaire,
  UVAO_questionnaire,
} from '../interface/questionnaire.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['问卷表'])
@Controller('/questionnaire')
export class QuestionnaireController extends BaseController {
  @Inject()
  service: QuestionnaireService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_questionnaire })
  async create(@Body() data: CDTO_questionnaire) {
    const dbData = await this.service.create(data);
    const result = new CVO_questionnaire(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_questionnaire })
  async query(
    @Query() filter: QDTO_questionnaire,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_questionnaire(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_questionnaire })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_questionnaire(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_questionnaire })
  async update(@Param('id') id: string, @Body() body: UDTO_questionnaire) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
